@@ -16,30 +16,34 @@ import os
 
 
 def _update_portlets_configure_zcml(configurator):
-    file_name = u'configure.zcml'
-    directory_path = configurator.variables['package_folder'] + '/portlets/'
+    file_name = u"configure.zcml"
+    directory_path = configurator.variables["package_folder"] + "/portlets/"
     file_path = directory_path + file_name
-    configure_example_file_path = configurator.variables['package_folder'] + '/portlets/configure.zcml.example'  # NOQA: E501
+    configure_example_file_path = (
+        configurator.variables["package_folder"] + "/portlets/configure.zcml.example"
+    )  # NOQA: E501
     file_list = os.listdir(os.path.dirname(directory_path))
     if file_name not in file_list:
         os.rename(configure_example_file_path, file_path)
 
-    with open(file_path, 'r') as xml_file:
+    with open(file_path, "r") as xml_file:
         parser = etree.XMLParser(remove_blank_text=True)
         tree = etree.parse(xml_file, parser)
         tree_root = tree.getroot()
         portlet_xpath = u"./plone:portlet[@name='{0}']".format(
-            configurator.variables['portlet_name'],
+            configurator.variables["portlet_name"],
         )
         if len(tree_root.xpath(portlet_xpath, namespaces=ZCML_NAMESPACES)):
-            print((
-                u'{0} already in configure.zcml, skip adding!'.format(
-                    configurator.variables['portlet_name'],
-                ),
-            ))
+            print(
+                (
+                    u"{0} already in configure.zcml, skip adding!".format(
+                        configurator.variables["portlet_name"],
+                    ),
+                )
+            )
             return
 
-    match_str = '-*- extra stuff goes here -*-'
+    match_str = "-*- extra stuff goes here -*-"
 
     insert_str = u"""
   <plone:portlet
@@ -50,43 +54,50 @@ def _update_portlets_configure_zcml(configurator):
     addview=".{5}.AddForm"
     editview=".{6}.EditForm" />
     """.format(
-        configurator.variables['portlet_configuration_name'],
-        configurator.variables['portlet_name_normalized'],
-        configurator.variables['data_provider_class_name'],
-        configurator.variables['portlet_name_normalized'],
-        configurator.variables['portlet_name_normalized'],
-        configurator.variables['portlet_name_normalized'],
-        configurator.variables['portlet_name_normalized'],
+        configurator.variables["portlet_configuration_name"],
+        configurator.variables["portlet_name_normalized"],
+        configurator.variables["data_provider_class_name"],
+        configurator.variables["portlet_name_normalized"],
+        configurator.variables["portlet_name_normalized"],
+        configurator.variables["portlet_name_normalized"],
+        configurator.variables["portlet_name_normalized"],
     )
 
     update_file(configurator, file_path, match_str, insert_str)
 
 
 def _update_portlets_xml(configurator):
-    file_name = u'portlets.xml'
-    directory_path = configurator.variables['package_folder'] + '/profiles/default/'  # NOQA: E501
+    file_name = u"portlets.xml"
+    directory_path = (
+        configurator.variables["package_folder"] + "/profiles/default/"
+    )  # NOQA: E501
     file_path = directory_path + file_name
-    configure_example_file_path = configurator.variables['package_folder'] + '/profiles/default/portlets.xml.example'  # NOQA: E501
+    configure_example_file_path = (
+        configurator.variables["package_folder"]
+        + "/profiles/default/portlets.xml.example"
+    )  # NOQA: E501
     file_list = os.listdir(os.path.dirname(directory_path))
     if file_name not in file_list:
         os.rename(configure_example_file_path, file_path)
 
-    with open(file_path, 'r') as xml_file:
+    with open(file_path, "r") as xml_file:
         parser = etree.XMLParser(remove_blank_text=True)
         tree = etree.parse(xml_file, parser)
         tree_root = tree.getroot()
         xpath_selector = "./portlet[@addview='{0}']".format(
-            configurator.variables['portlet_configuration_name'],
+            configurator.variables["portlet_configuration_name"],
         )
         if len(tree_root.xpath(xpath_selector, namespaces=ZCML_NAMESPACES)):
-            print((
-                u'{0} already in portlets.xml, skip adding!'.format(
-                    configurator.variables['portlet_configuration_name'],
-                ),
-            ))
+            print(
+                (
+                    u"{0} already in portlets.xml, skip adding!".format(
+                        configurator.variables["portlet_configuration_name"],
+                    ),
+                )
+            )
             return
 
-    match_str = u'<!-- Extra portlets here  -->'
+    match_str = u"<!-- Extra portlets here  -->"
 
     insert_str = u"""
   <portlet
@@ -108,25 +119,25 @@ def _update_portlets_xml(configurator):
 
   </portlet>
 """.format(
-        configurator.variables['portlet_configuration_name'],
-        configurator.variables['portlet_name'],
-        configurator.variables['portlet_name_normalized'],
-        configurator.variables['portlet_name_normalized'],
+        configurator.variables["portlet_configuration_name"],
+        configurator.variables["portlet_name"],
+        configurator.variables["portlet_name_normalized"],
+        configurator.variables["portlet_name_normalized"],
     )
 
     update_file(configurator, file_path, match_str, insert_str)
 
 
 def _delete_unnecessary_files(configurator):
-    directory_path = configurator.variables['package_folder']
-    configure_path = directory_path + '/portlets/'
-    file_name = u'configure.zcml.example'
+    directory_path = configurator.variables["package_folder"]
+    configure_path = directory_path + "/portlets/"
+    file_name = u"configure.zcml.example"
     file_list = os.listdir(os.path.dirname(configure_path))
     if file_name in file_list:
         file_path = configure_path + file_name
         os.remove(file_path)
-    portlets_xml_path = directory_path + '/profiles/default/'
-    file_name = u'portlets.xml.example'
+    portlets_xml_path = directory_path + "/profiles/default/"
+    file_name = u"portlets.xml.example"
     file_list = os.listdir(os.path.dirname(portlets_xml_path))
     if file_name in file_list:
         file_path = portlets_xml_path + file_name
@@ -134,21 +145,19 @@ def _delete_unnecessary_files(configurator):
 
 
 def _update_configure_zcml(configurator):
-    file_name = u'configure.zcml'
-    file_path = configurator.variables['package_folder'] + '/' + file_name
+    file_name = u"configure.zcml"
+    file_path = configurator.variables["package_folder"] + "/" + file_name
 
-    with open(file_path, 'r') as xml_file:
+    with open(file_path, "r") as xml_file:
         parser = etree.XMLParser(remove_blank_text=True)
         tree = etree.parse(xml_file, parser)
         tree_root = tree.getroot()
-        xpath_selector = "./include[@package='{0}']".format('.portlets')  # NOQA: E501
+        xpath_selector = "./include[@package='{0}']".format(".portlets")  # NOQA: E501
         if len(tree_root.xpath(xpath_selector, namespaces=ZCML_NAMESPACES)):
-            print((
-                u'.views already in configure.zcml, skip adding!',
-            ))
+            print((u".views already in configure.zcml, skip adding!",))
             return
 
-    match_str = '-*- extra stuff goes here -*-'
+    match_str = "-*- extra stuff goes here -*-"
     insert_str = u"""
   <include package=".portlets" />
 """
@@ -158,22 +167,26 @@ def _update_configure_zcml(configurator):
 def prepare_renderer(configurator):
     """Prepare rendering."""
     configurator = base_prepare_renderer(configurator)
-    configurator.variables['template_id'] = 'portlet'
-    portlet_name = configurator.variables['portlet_name']
+    configurator.variables["template_id"] = "portlet"
+    portlet_name = configurator.variables["portlet_name"]
     normalized_portlet_name = cc.snakecase(slugify(portlet_name))  # NOQA: E501
-    configurator.variables['portlet_name_normalized'] = normalized_portlet_name
+    configurator.variables["portlet_name_normalized"] = normalized_portlet_name
     portlet_config_name = cc.pascalcase(normalized_portlet_name)
-    configurator.variables['portlet_configuration_name'] = u'{0}.portlets.{1}'.format(  # NOQA: E501
-        configurator.variables['package.dottedname'],
+    configurator.variables[
+        "portlet_configuration_name"
+    ] = u"{0}.portlets.{1}".format(  # NOQA: E501
+        configurator.variables["package.dottedname"],
         portlet_config_name,
     )
-    configurator.variables['data_provider_class_name'] = u'I{0}Portlet'.format(
+    configurator.variables["data_provider_class_name"] = u"I{0}Portlet".format(
         portlet_config_name,
     )
-    configurator.target_directory = configurator.variables['package_folder']
-    package_name = configurator.variables['package.dottedname'].replace('.', '_')  # NOQA: E501
+    configurator.target_directory = configurator.variables["package_folder"]
+    package_name = configurator.variables["package.dottedname"].replace(
+        ".", "_"
+    )  # NOQA: E501
     browser_layer = cc.pascalcase(package_name)
-    configurator.variables['browser_layer'] = u'I{0}Layer'.format(
+    configurator.variables["browser_layer"] = u"I{0}Layer".format(
         browser_layer,
     )
 
@@ -187,7 +200,7 @@ def post_renderer(configurator):
     run_isort(configurator)
     git_commit(
         configurator,
-        u'Add portlet: {0}'.format(
-            configurator.variables['portlet_name'],
+        u"Add portlet: {0}".format(
+            configurator.variables["portlet_name"],
         ),
     )
